# GTool

[![License: MIT](https://img.shields.io/badge/License-MIT-yellowgreen.svg?style=flat-square)](https://opensource.org/licenses/MIT) [![Python 3.10](https://img.shields.io/badge/Python-3.10-blue.svg?style=flat-square&logo=python)](https://www.python.org/downloads/release/python-310/) [![PyPi Package](https://img.shields.io/badge/pip_install-GToolGenerator-yellow.svg?style=flat-square&logo=pypi)](https://pypi.org/project/GTool/)


Create cards in png format of your discord and hand them out for life! A module to generate the cards and another one that is the API itself. Enter if you prefer your own template, modify the values and start creating (JAJAJASJD, they are not nft's).

![Example Update](https://github.com/ElHaban3ro/GTool/blob/main/users/ElHaban3ro/target.png?raw=true)

#### Downlaod Proejct
```bash
git clone https://github.com/ElHaban3ro/GTool
```
or 

```bash
pip install GToolGenerator
```

#### Install the requirements.
```bash
pip install -r requirements.txt
```

*Remember, run the script from the main folder.*

#### Use

Start using the app by running the `GTool/api.py` file from the root folder. After turning on your server (technically the API) make your request to:
```
https://127.0.0.7:5000/generate/github/{github_user}/{color}
```

*(the ip may vary)*

At the moment we don't have the color option built in, so whatever color you set, it will be harmless. Note that this can be used as an API by opening a tunnel with, for example, Ngrok. 


#### Contact Me
[![Contact Twitter](https://img.shields.io/badge/Twitter-ElHaban3ro-9cf.svg?style=for-the-badge&logo=twitter)](https://twitter.com/ElHaban3ro) [![Contact Discord](https://img.shields.io/badge/GitHub-ElHaban3ro-lightgray?style=for-the-badge&logo=github)](https://github.com/ElHaban3ro)  [![JOIN SERVER](https://img.shields.io/badge/Discord-JOIN_TO_MY_SERVER-lightgray?style=for-the-badge&logo=discord)](https://discord.gg/NGp9YbYJ8F)
